@@ -19,30 +19,46 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: recur.pl,v 1.3 1996/02/11 20:25:23 curt Exp $
+# $Id: recur.pl,v 2.8 1997/02/28 21:21:58 curt Exp $
 # (Log is kept at end of this file)
 
 
+use strict;    # don't take no guff
+
+require "timelocal.pl";
+
+
+package CBB;
+
+my($key, $date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total);
+my($recur, $result, $update);
+my($future_days, $secs_per_day, $cur_date, $account);
+
+
 # specify the installed location of the necessary pieces.
-$cbb_incl_dir = "..";
-unshift(@INC, $cbb_incl_dir);
+$CBB::cbb_incl_dir = "..";
+unshift(@INC, $CBB::cbb_incl_dir);
 
 require "categories.pl";
 require "common.pl";
 require "engine.pl";
-require "timelocal.pl";
 
 
-($#ARGV >= 0) || 
-    die "Usage: $0 account";
+($#ARGV >= 0) || die "Usage: $0 account";
+
 
 # how many days to plan ahead
-$future_days = 366;		# approximately 1 year;
+#$future_days = 366;		# approximately 1 year;
+$future_days = 92;		# approximately 3 months;
 $secs_per_day = 86400;		# seconds per day;
 
 $cur_date = &raw_date;
 
 $account = shift(@ARGV);
+if ( $account !~ /\.cbb$/ ) {
+    die "Account name must end in '.cbb'\n";
+}
+
 (&load_trans($account) eq "ok") || die "Cannot open account:  $account";
 
 #-----------------------------------------------------------------------
@@ -118,14 +134,17 @@ close(RECUR);
 # Add all recuring transactions specified
 
 sub add_all_recurs {
-    local($line) = @_;
+    my($line) = @_;
+    my($days, $months, $years, $desc, $debit, $credit, $com, $cat, $begindate, 
+       $cutoff);
+    my($date, $dates, $key, $trans, @DATES);
 
     chop($line);
 
     ($days, $months, $years, $desc, $debit, $credit, $com, $cat,
      $begindate, $cutoff) = split(/\t/, $line);
 
-    if ( $begindate eq "" ) {
+    if ( ($begindate eq "") || ($begindate < $cur_date) ) {
 	$begindate = $cur_date;
     }
 
@@ -150,7 +169,11 @@ sub add_all_recurs {
     foreach $date (@DATES) {
 	print ".";
 	$trans = "$date\t\t$desc\t$debit\t$credit\t$cat\t$com\t?\t";
-	$key = &create_trans($trans);
+        if ($cat =~ m/^\[/) {
+            $key = &create_xfer($trans);
+        } else {
+            $key = &create_trans($trans);
+        }
     }
 }
 
@@ -160,26 +183,31 @@ print "\n";
 # Calculate cutoff date
 
 sub calc_cutoff {
-    local($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
+    my($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
         localtime(time);
+    my($cutoff_secs, $today_secs);
 
-    $today_secs = &timelocal(0, 0, 0, $cmday, $cmon, $cyear);
+    # print "calling timelocal with cmon = $cmon\n";
+    $today_secs = &main'timelocal(0, 0, 0, $cmday, $cmon, $cyear);
     $cutoff_secs = $today_secs + ($future_days * $secs_per_day);
 
     ($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
         localtime($cutoff_secs);
 
-    return "19$cyear" . &pad($cmon + 1) . &pad($cmday);  
+    return &century() . $cyear . &pad($cmon + 1) . &pad($cmday);  
 }
 
 
 # Generate a list of type 1 dates
 
 sub gen_dates_1 {
-    local($days, $months, $years, $begindate, $cutoff) = @_;
-    local($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
+    my($days, $months, $years, $begindate, $cutoff) = @_;
+    my($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
         localtime(time);
-    local($ldates) = "";
+    my($ldates) = "";
+    my($day, $month, $year, $tdays, $tmonth, $tyear);
+    my($this_date, $month_end, $next_month);
+    my(@DAYS, @MONTHS, @YEARS);
 
     # print "$days - $months - $years\n";
 
@@ -195,14 +223,15 @@ sub gen_dates_1 {
 
     foreach $year (@YEARS) {
 	foreach $month (@MONTHS) {
-	    # print "19$year" . &pad($month) . "\n";
+	    # print &century() . $year . &pad($month) . "\n";
 	    if ( $month == 12 ) {
 		$tyear = $year + 1; $tmonth = 1;
 	    } else {
 		$tyear = $year; $tmonth = $month + 1;
 	    }
 	    # note in perl the months start at 0 ... :(
-	    $next_month = &timelocal(0, 0, 0, 1, ($tmonth - 1), $tyear);
+	    # print "calling timelocal with tmonth = $tmonth \n";
+	    $next_month = &main'timelocal(0, 0, 0, 1, ($tmonth - 1), $tyear);
 	    # subtract the number of seconds in a day to get the last
 	    # day of the previous month
 	    $month_end = $next_month - $secs_per_day;
@@ -225,7 +254,7 @@ sub gen_dates_1 {
 
 	    @DAYS = split(/,/, $tdays);
 	    foreach $day (@DAYS) {
-		$this_date =  "19$year" . &pad($month) . &pad($day);
+		$this_date = &century() . $year . &pad($month) . &pad($day);
 		if ( ($this_date >= $begindate) && ($this_date <= $cutoff) ) {
 		    # print "$this_date\n";
 		    if ( $ldates eq "" ) {
@@ -245,20 +274,23 @@ sub gen_dates_1 {
 # Generate a list of type 2 dates
 
 sub gen_dates_2 {
-    local($start, $incr, $junk, $begindate, $cutoff) = @_;
-    local($ldates) = "";
-    local($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst);
-    local($junk, $syear, $smonth, $sday) = $start =~ /(\d\d)(\d\d)(\d\d)(\d\d)/;
+    my($start, $incr, $junk, $begindate, $cutoff) = @_;
+    my($ldates) = "";
+    my($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst);
+    my($scentury, $syear, $smonth, $sday) = 
+	$start =~ /(\d\d)(\d\d)(\d\d)(\d\d)/;
+    my($secs, $sincr, $start_secs, $this_date);
 
     # print "$syear - $smonth - $sday\n";
 
-    $start_secs = &timelocal(0, 0, 0, $sday, ($smonth - 1), $syear);
+    # print "calling timelocal with smonth = $smonth\n";
+    $start_secs = &main'timelocal(0, 0, 0, $sday, ($smonth - 1), $syear);
     $sincr = $incr * $secs_per_day;
 
     $secs = $start_secs;
     ($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
 	localtime($secs);
-    $this_date = "19$cyear" . &pad($cmon + 1) . &pad($cmday);
+    $this_date = &century() . $cyear . &pad($cmon + 1) . &pad($cmday);
     while ( $this_date <= $cutoff ) {
 	if ( $this_date >= $begindate ) {
 	    if ( $ldates eq "" ) {
@@ -271,7 +303,7 @@ sub gen_dates_2 {
 	$secs += $sincr;
 	($csec,$cmin,$chour,$cmday,$cmon,$cyear,$cwday,$cyday,$cisdst) = 
 	    localtime($secs);
-	$this_date = "19$cyear" . &pad($cmon + 1) . &pad($cmday);
+	$this_date = &century() . $cyear . &pad($cmon + 1) . &pad($cmday);
     }
 
     return $ldates;
@@ -280,13 +312,36 @@ sub gen_dates_2 {
 
 #----------------------------------------------------------------------------
 # $Log: recur.pl,v $
-# Revision 1.3  1996/02/11  20:25:23  curt
-# Added support for effective date range.
+# Revision 2.8  1997/02/28 21:21:58  curt
+# Fixed some problems introduced by using "use strict"
 #
-# Revision 1.2  1996/01/19  02:11:14  curt
-# A couple of tweaks to make this more usable.
+# Revision 2.7  1997/02/19 18:09:09  curt
+# Fixed some residual oversites from switching to "use strict".
 #
-# Revision 1.1  1996/01/18  05:15:51  curt
-# Initial Revision ... not done, but the hard stuff is working.
+# Revision 2.6  1997/01/18 17:26:39  curt
+# Added "use strict" pragma to enforce good scoping habits.
 #
-
+# Revision 2.5  1996/10/03 04:49:08  curt
+# Fixed an inconsistency in &raw_date() in common.pl (with how it was
+# called.)
+#
+# Version now is 0.67-beta-x
+#
+# Revision 2.4  1996/10/03 03:53:42  curt
+# CBB now determines the current century automatically ... no need for it
+# to be hard coded.  Removed all hardcoded instances of the century (especially
+# in reports.pl and recur.pl)
+#
+# Added an optional --debug flag to the invocation of CBB.
+#
+# Revision 2.3  1996/09/17 19:41:10  curt
+# Add support for recurring transfer transactions.
+#
+# Revision 2.2  1996/07/13 02:58:24  curt
+# Misc. changes.
+#
+# Revision 2.1  1996/02/27  05:36:04  curt
+# Just stumbling around a bit with cvs ... :-(
+#
+# Revision 2.0  1996/02/27  04:43:14  curt
+# Initial 2.0 revision.  (See "Log" files for old history.)
