@@ -1,48 +1,40 @@
-# LaTeX2HTML 98.2 beta6 (August 14th, 1998)
+# LaTeX2HTML 96.1-h (September 30, 1996)
 # Associate internals original text with physical files.
 
-
-$key = q/sec:normalinstall/;
+$key = q/sectransfer/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:tut-edit/;
+$key = q/secmigrain/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:install-latest/;
+$key = q/figgeneral/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:impquick/;
+$key = q/figcheck/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:viewcat/;
+$key = q/figdate/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:editing/;
+$key = q/figcbbrctcl/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:transfer/;
+$key = q/secnormalinstall/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/sec:migrain/;
+$key = q/secviewcat/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/fig:date/;
+$key = q/sectutedit/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/fig:check/;
+$key = q/secimpquick/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
-
-$key = q/fig:general/;
+$key = q/secediting/;
+$ref_files{$key} = "$dir".q|cbb-man.html|; 
+$noresave{$key} = "$nosave";
+$key = q/secinstalllatest/;
 $ref_files{$key} = "$dir".q|cbb-man.html|; 
 $noresave{$key} = "$nosave";
 
