@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started April 22, 1994.
 #
-#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994 - 1997  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,15 +19,20 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: file.pl,v 1.3 1996/01/21 02:18:49 curt Exp $
+# $Id: file.pl,v 2.5 1997/01/18 03:28:43 curt Exp $
 # (Log is kept at end of this file)
 
 
+package CBB;
+
+use strict;   # don't take no guff
+
+
 # given a directory and an extension mask (: separated list) return a
 # list of files that match (including all directories)
 sub get_files {
-    local($dir, $mask) = split(/ +/, $_[0]);
-    local($file, $ext, $count, @files, @sorted);
+    my($dir, $mask) = split(/ +/, $_[0]);
+    my($file, $ext, $count, @files, @sorted);
 
     print DEBUG "Directory = $dir\n";
     print DEBUG "Mask = $mask\n";
@@ -63,14 +68,23 @@ sub get_files {
 
 # ----------------------------------------------------------------------------
 # $Log: file.pl,v $
-# Revision 1.3  1996/01/21  02:18:49  curt
-# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
-#                  log.pl memorized.pl reports.pl wrapper.pl
-#   Updated copyright date.
+# Revision 2.5  1997/01/18 03:28:43  curt
+# Added "use strict" pragma to enforce good scoping habits.
 #
-# Revision 1.2  1995/08/03  22:59:01  curt
-# Added work around to avoid perl5 seg fault bug.
+# Revision 2.4  1996/12/17 14:53:56  curt
+# Updated copyright date.
 #
-# Revision 1.1  1995/04/24  02:00:04  curt
-# Herein lies some file support routines.
+# Revision 2.3  1996/12/11 18:33:35  curt
+# Ran a spell checker.
 #
+# Revision 2.2  1996/07/13 02:57:43  curt
+# Version 0.65
+# Packing Changes
+# Documentation changes
+# Changes to handle a value in both debit and credit fields.
+#
+# Revision 2.1  1996/02/27  05:35:42  curt
+# Just stumbling around a bit with cvs ... :-(
+#
+# Revision 2.0  1996/02/27  04:42:56  curt
+# Initial 2.0 revision.  (See "Log" files for old history.)
