@@ -5,7 +5,7 @@
 #
 #  Written by Curtis Olson.  Started August 25, 1994.
 #
-#  Copyright (C) 1994 - 1999  Curtis L. Olson  - curt@me.umn.edu
+#  Copyright (C) 1994 - 1997  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,8 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: file.tcl,v 1.2 2000/01/04 22:49:57 curt Exp $
+# $Id: file.tcl,v 2.17 1997/06/12 21:53:13 curt Exp $
+# (Log is kept at end of this file)
 
 
 #------------------------------------------------------------------------------
@@ -55,13 +56,7 @@ proc acctNew {} {
 	}
     } 
 
-    # use starting directory of current file if it exists
-    if { [info exists cbb(cur_file)] && \
-	    ("[file dirname $cbb(cur_file)]" != "") } {
-	set newacct(name) "[file dirname $cbb(cur_file)]/"
-    } else {
-	set newacct(name) "[mypwd]/"
-    }
+    set newacct(name) "[mypwd]/"
     if { $cbb(debug) } { puts $newacct(name) }
 
     cbbWindows.newacct
@@ -168,12 +163,12 @@ proc cbbWindows.newacct {} {
     frame .newacct.frame.b
 
     label .newacct.frame.label -text \
-	"Enter New Account Base Name (including directory) and Description"
+	"Enter New Account Base Name and Description"
 
     label .newacct.frame.n.label -text "New Acct"
     entry .newacct.frame.n.entry -textvariable newacct(name) -relief sunken \
 	    -font $cbb(default_font)
-    # .newacct.frame.n.entry icursor 0
+    .newacct.frame.n.entry icursor 0
     .newacct.frame.n.entry icursor end
     # tk_entrySeeCaret .newacct.frame.n.entry
 
@@ -317,8 +312,7 @@ proc acctLoadFile file {
 
     wm title . "[file tail $argv0] - [file tail $file]"
     wm iconname . "[file tail $argv0] - [file tail $file]"
-    . configure -cursor watch
-    .trans.list configure -cursor watch
+    # . configure -cursor watch
     .status.line configure -text "Loading transactions from [file tail $file]"
     update
 
@@ -367,8 +361,7 @@ proc acctLoadFile file {
     goto $start_pos
     clear_entry_area
 
-    . configure -cursor left_ptr
-    .trans.list configure -cursor xterm
+    # . configure -cursor left_ptr
 
     # hash out the memorized transactions
     if { $cbb(debug) } { puts "Hashing memorized transactions" }
@@ -410,8 +403,6 @@ proc acctSave {} {
         return
     }
 
-    . configure -cursor watch
-    .trans.list configure -cursor watch
     .status.line configure \
 	    -text "Saving transactions to [file tail $cbb(cur_file)]"
     update
@@ -421,13 +412,7 @@ proc acctSave {} {
     gets $eng result
     if { $cbb(debug) } { puts "saving transactions ... $result" }
 
-    . configure -cursor left_ptr
-    .trans.list configure -cursor xterm
-
     if { "$result" != "ok" } {
-	. configure -cursor left_ptr
-	.trans.list configure -cursor xterm
-
         cbbWindow.ok "Error saving ``$cbb(cur_file)'':  $result.  You are \
 		advised to use the ``Save As'' function to save to a different \
 		file name."
@@ -440,9 +425,6 @@ proc acctSave {} {
     if { $cbb(debug) } { puts "saving categories ... $result" }
 
     if { "$result" != "ok" } {
-	. configure -cursor left_ptr
-	.trans.list configure -cursor xterm
-
         cbbWindow.ok "Error saving \
 		``[file dirname $cbb(cur_file)]/categories'':  \
 		$result.  Recent changes to your categories list may not \
@@ -454,9 +436,6 @@ proc acctSave {} {
 
     # ok we are clean again
     acctSetClean
-
-    . configure -cursor left_ptr
-    .trans.list configure -cursor xterm
 }
 
 
@@ -517,8 +496,9 @@ proc acctImportFile args {
     global cbb eng key date nicedate year month day check desc debit credit cat
     global nicecat com cleared total
 
-    set file [lindex $args 0]
-    set type [lindex $args 1]
+    set arglist [split $args]
+    set file [lindex $arglist 0]
+    set type [lindex $arglist 1]
 
     # clear out the old ... not any more
     # acctNewClear
@@ -545,9 +525,9 @@ proc acctImportFile args {
     }
 
     # clear our list box
-    .trans.list configure -state normal
     .trans.list delete 0.0 end
 
+    .trans.list configure -state normal
     set flag 0
     puts $eng "all_trans $cbb(date_fmt)"; flush $eng
     gets $eng line1
@@ -693,9 +673,6 @@ proc cbbrcSave {} {
     puts $rchandle "# Enable Balloon Help:  0 = disabled, 1 = enabled"
     puts $rchandle "set cbb(balloon,on) $cbb(balloon,on)"
     puts $rchandle ""
-    puts $rchandle "# Enable Splash Screen:  0 = disabled, 1 = enabled"
-    puts $rchandle "set cbb(splash) $cbb(splash)"
-    puts $rchandle ""
     puts $rchandle "# Auto-highlight entry fields:  0 = disabled, 1 = enabled"  
     puts $rchandle "set cbb(auto_hilite) $cbb(auto_hilite)"
     puts $rchandle ""
@@ -723,7 +700,6 @@ proc cbbrcSave {} {
     puts $rchandle "# Startdate ..."
     puts $rchandle "set cbb(use_sdate) $cbb(use_sdate)"
     puts $rchandle "set cbb(sdate) \"$cbb(sdate)\""
-    puts $rchandle "set cbb(report_sdate) \"$cbb(report_sdate)\""
     puts $rchandle ""
     puts $rchandle "# Account Cache ..."
     puts $rchandle "set cbb(cache) $cbb(cache)"
@@ -733,10 +709,6 @@ proc cbbrcSave {} {
     puts $rchandle "set cbb(encrypt) \"$cbb(encrypt)\""
     puts $rchandle "set cbb(decrypt) \"$cbb(decrypt)\""
     puts $rchandle ""
-    puts $rchandle "# Duplicate Entries ..."
-    puts $rchandle "set cbb(duplicate) $cbb(duplicate)"
-    puts $rchandle "set cbb(cmpfields) $cbb(cmpfields)"
-    puts $rchandle ""
     puts $rchandle "# Fonts ..."
     puts $rchandle "set cbb(msg_text_font) \"$cbb(msg_text_font)\""
     puts $rchandle "set cbb(button_font) \"$cbb(button_font)\""
@@ -752,10 +724,6 @@ proc cbbrcSave {} {
     puts $rchandle "set cbb(hilite_color) \"$cbb(hilite_color)\""
     puts $rchandle "set cbb(list_line1_color) \"$cbb(list_line1_color)\""
     puts $rchandle "set cbb(list_line2_color) \"$cbb(list_line2_color)\""
-    puts $rchandle "set cbb(trans_text_color) \"$cbb(trans_text_color)\""
-    puts $rchandle "set cbb(trans_neg_color) \"$cbb(trans_neg_color)\""
-    puts $rchandle "set cbb(future_color) \"$cbb(future_color)\""
-    puts $rchandle "set cbb(future_neg_color) \"$cbb(future_neg_color)\""
     puts $rchandle ""
     puts $rchandle "# External web browser"
     puts $rchandle "set cbb(web_browser) \"$cbb(web_browser)\""
@@ -795,3 +763,109 @@ proc setup_auto_save {} {
 	setup_auto_save
     }
 }
+
+
+# ----------------------------------------------------------------------------
+# $Log: file.tcl,v $
+# Revision 2.17  1997/06/12 21:53:13  curt
+# Applied more patches from Martin Schenk <schenkm@ping.at>.  His changes
+# greatly improved and developed the preferences menu so it is now actually
+# usable to set preferences.
+# Current data file is now saved in ~/.cbbcur.tcl
+#
+# Revision 2.16  1997/05/06 01:00:26  curt
+# Added patches contributed by Martin Schenk <schenkm@ping.at>
+# - Default to umask of 066 so .CBB files get created rw by owner only
+# - Added support for pgp encrypting data files
+# - Added support for displaying only recent parts of files (avoids
+#   waiting to load in lots of old txns you don't currently need.)
+# - Added a feature to "cache" whole accounts in the perl engine so
+#   that switching between accounts can be faster.
+# - The above options can be turned on/off via the preferrences menu.
+#
+# Revision 2.15  1997/04/07 21:13:32  curt
+# Add a $cbb(web_browser) variable which can be set from ~/.cbbrc.tcl
+# If netscape is the browser, and there is a copy running, don't start
+# a new copy.
+#
+# Revision 2.14  1997/04/03 03:54:47  curt
+# Enable auto save without prompting when switching to a new account.
+# Contributed by Jonathan I. Kamens <jik@kamens.brookline.ma.us>
+#
+# Revision 2.13  1997/03/04 03:22:38  curt
+# Fixed bug which showed up when hitting '+' in a blank check # field after
+# an account had been loaded, but before any transactions with a check number
+# had been added.
+#
+# Revision 2.12  1997/01/16 19:15:39  curt
+# Miscellaneous interface tweaks.
+#
+# Revision 2.11  1997/01/13 19:31:48  curt
+# Fixed a little typo which caused .qif imports to go into an infinite loop.
+#
+# Revision 2.10  1997/01/09 04:02:59  curt
+# Allow user to specify colors of alternating transaction lines.
+#
+# Revision 2.9  1997/01/09 03:56:57  curt
+# Added contrib script loan.pl.
+# User sizable account list.
+# Removed some old gnuplot baggage from install.pl.
+#
+# Revision 2.8  1997/01/02 04:38:34  curt
+# Changes over the 1996 holidays:
+#   - Converted listbox to text widget.  This allows us to do nice
+#     things with alternating background colors, highliting, red
+#     negative numbers, etc.
+#   - Negative transactions are now drawn in red.
+#   - Added a Goto <Today> option.
+#   - <Home> & <End> were double bound.  Now, listbox can be traversed with
+#     <Meta-Home> and <Meta-End>
+#
+# Revision 2.7  1996/12/17 14:53:56  curt
+# Updated copyright date.
+#
+# Revision 2.6  1996/12/16 04:18:17  curt
+# Continuing the great overhaul of December 1996.
+#
+# Revision 2.5  1996/12/14 17:15:22  curt
+# The great overhaul of December '96.
+#
+# Revision 2.4  1996/12/11 18:33:36  curt
+# Ran a spell checker.
+#
+# Revision 2.3  1996/12/11 04:32:28  curt
+# Several minor tweaks.
+#
+# Revision 2.2  1996/12/08 07:39:59  curt
+# Rearranged quite a bit of code.
+# Put most global variables in cbb() structure.
+#
+# Revision 2.1  1996/12/07 20:38:14  curt
+# Renamed *.tk -> *.tcl
+#
+# Revision 2.6  1996/10/24 15:09:33  curt
+# Version number updates.
+#
+# Revision 2.5  1996/10/23 02:28:21  curt
+# Display an error message if a problem is encountered saving the account or
+# categories.
+#
+# Revision 2.4  1996/09/30 15:14:36  curt
+# Updated CBB URL, and hardwired wish path.
+#
+# Revision 2.3  1996/07/13 02:57:44  curt
+# Version 0.65
+# Packing Changes
+# Documentation changes
+# Changes to handle a value in both debit and credit fields.
+#
+# Revision 2.2  1996/03/03  00:16:12  curt
+# Modified Files:  cbb categories.pl wrapper.pl file.tk main.tk menu.tk
+#   Added an account list at the bottom of the screen.  Thanks to:
+#   Cengiz Alaettinoglu <cengiz@ISI.EDU> for this great addition.
+#
+# Revision 2.1  1996/02/27  05:35:43  curt
+# Just stumbling around a bit with cvs ... :-(
+#
+# Revision 2.0  1996/02/27  04:42:57  curt
+# Initial 2.0 revision.  (See "Log" files for old history.)
