@@ -5,7 +5,7 @@
 #
 #  Written by Curtis Olson.  Started August 25, 1994.
 #
-#  Copyright (C) 1994 - 1999  Curtis L. Olson  - curt@me.umn.edu
+#  Copyright (C) 1994 - 1997  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,8 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: main.tcl,v 1.6 2000/01/05 18:44:15 curt Exp $
+# $Id: main.tcl,v 2.27 1997/06/12 21:53:14 curt Exp $
+# (Log is kept at end of this file)
 
 
 #------------------------------------------------------------------------------
@@ -34,8 +35,6 @@ proc setup_main {} {
     # Setup main window parameters
 
     wm title . "[file tail $argv0] - $cbb(cur_file)"
-    wm command . "[file tail $argv0]"
-    wm group . .
     wm iconname . "[file tail $argv0] - $cbb(cur_file)"
     wm iconbitmap . @$lib_path/images/$cbb(icon_xbm)
     # specify absolute placement
@@ -64,7 +63,6 @@ proc setup_main {} {
     setup_file_prefs_menu .menubar
     setup_prefs_crypt_menu .menubar
     setup_prefs_appear_menu .menubar
-    setup_prefs_duplicate_menu .menubar
     setup_functions_goto_menu .menubar
 
 #   if { $cbb(devel) == 0 } {
@@ -136,11 +134,11 @@ proc setup_headers {} {
     global cbb
 
     label .head.line1 -font $cbb(fixed_header_font) \
-            -text [format "%5s  %-10s  %-15s  %9s  %9s  %1s  %9s" \
+            -text [format "%5s  %-8s  %-15s  %9s  %9s  %1s  %9s" \
             "Chk #" "Date" "Description" "Debit" "Credit" "" "Total"] \
             -padx 5 -pady -1 -foreground $cbb(head_color)
     label .head.line2 -font $cbb(fixed_header_font) \
-            -text [format "%5s  %-10s  %-15s  %-9s" \
+            -text [format "%5s  %-8s  %-15s  %-9s" \
             "" "" "Comment" "Category"] -padx 4 -pady -1 \
 	    -foreground $cbb(head_color)
     pack .head.line1 -side top -anchor w
@@ -155,6 +153,9 @@ proc setup_headers {} {
 proc setup_listbox {} {
     global cbb
 
+### listbox .trans.list -width $cbb(list_width) -height $cbb(list_height) \
+###	    -takefocus 0 -exportselection false \
+###	    -yscrollcommand ".trans.scroll set" -font $cbb(fixed_font)
     text .trans.list -width $cbb(list_width) -height $cbb(list_height) \
 	    -spacing1 1 -takefocus 0 -exportselection false \
 	    -font $cbb(fixed_font) -wrap none \
@@ -162,22 +163,19 @@ proc setup_listbox {} {
 	    -yscrollcommand ".trans.scroll set"
 
     if {[winfo depth .] > 1} {
+#	.trans.list tag configure color1 -background grey94 \
+#		-foreground black
+#	.trans.list tag configure color2 -background grey78 \
+#		-foreground black
+#	.trans.list tag configure color2 -underline 1
 	.trans.list tag configure color1 -background $cbb(list_line1_color) \
-		-foreground $cbb(trans_text_color)
+		-foreground black
 	.trans.list tag configure color2 -background $cbb(list_line2_color) \
-		-foreground $cbb(trans_text_color)
+		-foreground black
 	.trans.list tag configure negcolor1 -background $cbb(list_line1_color) \
-		-foreground $cbb(trans_neg_color)
+		-foreground red
 	.trans.list tag configure negcolor2 -background $cbb(list_line2_color) \
-		-foreground $cbb(trans_neg_color)
-	.trans.list tag configure futcolor1 -background $cbb(list_line1_color) \
-		-foreground $cbb(future_color)
-	.trans.list tag configure futcolor2 -background $cbb(list_line2_color) \
-		-foreground $cbb(future_color)
-	.trans.list tag configure futnegcolor1 -background \
-		$cbb(list_line1_color) -foreground $cbb(future_neg_color)
-	.trans.list tag configure futnegcolor2 -background \
-		$cbb(list_line2_color) -foreground $cbb(future_neg_color)
+		-foreground red
 
 	.trans.list tag configure cbbSel -background $cbb(hilite_color) \
 		-foreground black
@@ -220,7 +218,7 @@ proc setup_entry_area {} {
     pack .entry.line2 -side top -fill x -expand 1
 
     entry .entry.line1.check -relief sunken -width 5 -textvariable check
-    entry .entry.line1.date -width 10 -relief sunken -textvariable nicedate
+    entry .entry.line1.date -width 8 -relief sunken -textvariable nicedate
     entry .entry.line1.desc -width 15 -relief sunken -textvariable desc
     entry .entry.line1.debit -width 9 -relief sunken -textvariable debit
     entry .entry.line1.credit -width 9 -relief sunken -textvariable credit
@@ -229,23 +227,23 @@ proc setup_entry_area {} {
     cbb_set_balloon .entry.line1.done "Done entering <Enter>"
 
     pack .entry.line1.check -side left
-    pack .entry.line1.date -padx 8 -side left
+    pack .entry.line1.date -padx 7 -side left
     pack .entry.line1.desc -side left
-    pack .entry.line1.debit -padx 8 -side left
+    pack .entry.line1.debit -padx 7 -side left
     pack .entry.line1.credit -side left
-    pack .entry.line1.clear -padx 8 -side left
+    pack .entry.line1.clear -padx 6 -side left
     pack .entry.line1.done -side right
 
-    label .entry.line2.space -width 17
+    label .entry.line2.space -width 15
     entry .entry.line2.com -width 15 -relief sunken -textvariable com
     entry .entry.line2.cat -width 9 -relief sunken -textvariable cat
     button .entry.line2.cancel -image cancel -command clear_entry_area \
 	    -takefocus 0
     cbb_set_balloon .entry.line2.cancel "Cancel changes and start over <Meta-N>"
 
-    pack .entry.line2.space -padx 5 -side left
+    pack .entry.line2.space -padx 6 -side left
     pack .entry.line2.com -side left
-    pack .entry.line2.cat -padx 8 -side left
+    pack .entry.line2.cat -padx 7 -side left
     pack .entry.line2.cancel -side right
 
     # setup some bindings
@@ -283,100 +281,26 @@ proc setup_entry_area {} {
     }
 
     bind .entry.line1.date + {
-	set date [inc_date $date]
-	# puts "returned date = $date"
-	set nicedate [date_to_nicedate $date]
+	set nicedate [inc_date $nicedate]
 	%W icursor end
 	break
     }
     bind .entry.line1.date = {
-	set date [inc_date $date]
-	set nicedate [date_to_nicedate $date]
+	set nicedate [inc_date $nicedate]
 	%W icursor end
 	break
     }
 
     bind .entry.line1.date - {
-	set date [dec_date $date]
-	set nicedate [date_to_nicedate $date]
+	set nicedate [dec_date $nicedate]
 	%W icursor end
 	break
     }
     bind .entry.line1.date _ {
-	set date [dec_date $date]
-	set nicedate [date_to_nicedate $date]
+	set nicedate [dec_date $nicedate]
 	%W icursor end
 	break
     }
-
-    # setup custom math bindings for debit && credit fields
-    if { [file exists "~/.cbbmath"] } {
-        setup_custom_math "~/.cbbmath"
-    }
-}
-
-
-#------------------------------------------------------------------------------
-# Setup custom math bindings for debit and credit fields
-#
-# This contains some real ugliness ... I hope I never have to come back here
-# to debug ... :-)
-#------------------------------------------------------------------------------
-
-proc setup_custom_math { filename } {
-    global env
-
-    set filehandle [open "$filename" r]
-    while { [gets $filehandle line] >= 0 } {
-
-	if { "[string range $line 0 0]" == "#" } {
-	    # ignore this line
-	} elseif { [string length $line] < 3  } {
-	    # ignore this line
-        } else {
-	    set pieces [split $line "\t"]
-
-	    set bindkey [lindex $pieces 0]
-	    set units [lindex $pieces 1]
-	    set expr [lindex $pieces 2]
-	    set x 0
-
-	    set bind_cmd "bind .entry.line1.debit $bindkey { \
-		set x \$debit;
-		set debit \[ expr $expr \];
-                if { \[regexp \"\\\[(\\\]\\\[0-9\\\.\\\-\\\]+ $units\\\[)\\\]\" \$com\] } {
-		    regsub \"\\\[(\\\]\\\[0-9\\\.\\\-\\\]+ $units\\\[)\\\]\" \$com \"(-\$x $units)\" com
-		} else {
-		    if { \"\$com\" == \"\" } {
-			set com \"(-\$x $units)\";
-		    } else {
-			set com \"\$com (-\$x $units)\";
-		    }
-		}
-		break
-	    }"
-	    # puts $bind_cmd
-	    eval $bind_cmd
-
-	    set bind_cmd "bind .entry.line1.credit $bindkey { \
-		set x \$credit;
-		set credit \[ expr $expr \];
-                if { \[regexp \"\\\[(\\\]\\\[0-9\\\.\\\-\\\]+ $units\\\[)\\\]\" \$com\] } {
-		    regsub \"\\\[(\\\]\\\[0-9\\\.\\\-\\\]+ $units\\\[)\\\]\" \$com \"(\$x $units)\" com
-		} else {
-		    if { \"\$com\" == \"\" } {
-			set com \"(\$x $units)\";
-		    } else {
-			set com \"\$com (\$x $units)\";
-		    }
-		}
-		break
-	    }"
-	    # puts $bind_cmd
-	    eval $bind_cmd
-	}
-    }
-    close $filehandle
 }
 
 
@@ -385,51 +309,50 @@ proc setup_custom_math { filename } {
 #------------------------------------------------------------------------------
 
 proc setup_command_bar { } {
-    global cbb words
+    global cbb
 
     option add *font $cbb(button_font)
 
-    button .bar.new -text $words(button_new) -takefocus 0 \
-	    -command { clear_entry_area }
-    cbb_set_balloon .bar.new $words(button_new_balloon)
+    button .bar.new -text "New" -takefocus 0 -command { clear_entry_area }
+    cbb_set_balloon .bar.new "Cancel changes and start a new transaction \
+	    <Meta-N>"
 
-    button .bar.edit -text $words(button_edit) -takefocus 0 -command {
+    button .bar.edit -text "Edit" -takefocus 0 -command {
 	if { [listGetCurTrans] >= 1 } {
 	    update_entry_area [listGetCurTrans].0
 	}
     }
-    cbb_set_balloon .bar.edit $words(button_edit_balloon)
+    cbb_set_balloon .bar.edit "Edit the selected transaction <Meta-E>"
 
-    button .bar.delete -text $words(button_delete) -takefocus 0 \
+    button .bar.delete -text "Delete" -takefocus 0 \
             -command {
 	if { [listGetCurTrans] >= 1 } {
 	    if { $cbb(debug) } { puts "Delete [listGetCurTrans].0" }
 	    delete_trans [listGetCurTrans].0
 	}
     } 
-    cbb_set_balloon .bar.delete $words(button_delete_balloon)
+    cbb_set_balloon .bar.delete "Delete the selected transaction"
 
-    button .bar.splits -text $words(button_splits) -takefocus 0 -command { 
+    button .bar.splits -text "Splits" -takefocus 0 -command { 
 	cbbWindow.splits
 	tkwait window .splits
     }
-    cbb_set_balloon .bar.splits $words(button_splits_balloon)
+    cbb_set_balloon .bar.splits "Open the splits window <Meta-S>"
 
-    button .bar.balance -text $words(button_balance) -takefocus 0 \
-	    -command { balance }
-    cbb_set_balloon .bar.balance $words(button_balance_balloon)
+    button .bar.balance -text "Balance" -takefocus 0 -command { balance }
+    cbb_set_balloon .bar.balance "Open the balance window"
 
-    button .bar.save -text $words(button_save) -takefocus 0 -command {
+    button .bar.save -text "Save" -takefocus 0 -command {
 	if { $cbb(cur_file) != "noname.cbb" } {
 	    acctSave
 	} else {
 	    acctSaveAs
 	}
     }
-    cbb_set_balloon .bar.save $words(button_save_balloon_clean)
+    cbb_set_balloon .bar.save "Save the current file"
 
-    button .bar.quit -text $words(button_quit) -takefocus 0 -command { cbbQuit }
-    cbb_set_balloon .bar.quit $words(button_quit_balloon)
+    button .bar.quit -text "Quit" -takefocus 0 -command { cbbQuit }
+    cbb_set_balloon .bar.quit "Quit <Meta-Q>"
 
     pack .bar.new .bar.edit .bar.delete .bar.splits .bar.balance .bar.save \
 	.bar.quit -side left -fill x -expand 1 -padx 2 -pady 1
@@ -449,14 +372,13 @@ proc setup_acct_listbox {} {
 
     bind .acct.list <Double-Button> {
 	if { "[.acct.list curselection]" != "" } {
-	    set file [.acct.list get [.acct.list curselection]].cbb
 	    if { [acctIsDirty] } {
 		if { $cbb(auto_save) } {
 		    acctSave
 		} else {
 		    cbbWindow.yesno "You have not saved your current changes.  \
 			    Would you like to save before loading a new \
-			    account?" yes
+			    account?"
 		    tkwait window .yesno
 		    
 		    if { "$yesno(result)" == "yes" } {
@@ -467,6 +389,7 @@ proc setup_acct_listbox {} {
 		    }
 		}
 	    }
+	    set file [.acct.list get [.acct.list curselection]].cbb
 	    set dname  [file dirname $cbb(cur_file)]
 	    regsub " .*$" $file "" file
 	    acctLoadFile $dname/$file.cbb
@@ -489,18 +412,13 @@ proc load_acct_listbox {} {
     .acct.list delete 0 [.acct.list size]
     foreach i $a {
 	set b "no files found"
-	set c "no files found"
 	if { $cbb(use_crypt) } {
 	    catch { set b [exec sh -c "$cbb(decrypt) $cbb(crypt_code) < \
 		    $dname/$i 2>/dev/null | grep '# Current Balance = '"]}
-	    catch { set c [exec sh -c "$cbb(decrypt) $cbb(crypt_code) < \
-		    $dname/$i 2>/dev/null | grep '# Ending Balance = '"]}
 	} else {
 	    catch {set b [exec grep "# Current Balance = " $dname/$i]}
-	    catch {set c [exec grep "# Ending Balance = " $dname/$i]}
 	}
 	regsub ".* " $b "" b
-	regsub ".* " $c "" c
 	regsub "\.cbb" $i "" i
 
 	# get the account description
@@ -512,9 +430,7 @@ proc load_acct_listbox {} {
 	    set desc [lindex $pieces 0]
 	}
 
-	# .acct.list insert end [format "%-16s  %-37s  %11s" $i $desc $b]
-	.acct.list insert end \
-		[format "%-16s  %-26.26s  %11s  %11s" $i $desc $b $c]
+	.acct.list insert end [format "%-16s  %-37s  %11s" $i $desc $b]
     }
 
     update
@@ -538,13 +454,10 @@ proc setup_status_line { } {
 # Functions for the text box
 #------------------------------------------------------------------------------
 
-# $date_now should be the calendar on the wall date, nothing to do with the
-# date of the current transaction.
 proc listAddTrans {line1 line2} {
-    global cbb date start_pos date_now
+    global cbb date start_pos
 
-    if { $cbb(debug) } { puts " --> $line1" }
-    set total [string range $line1 60 69]
+    set total [string range $line1 58 67]
     if { $cbb(debug) } { puts " --> $total" }
     set total [expr $total + 0]
     if { $cbb(debug) } { puts " --> $total" }
@@ -554,28 +467,15 @@ proc listAddTrans {line1 line2} {
 	set negative 0
     }
 
-    if ![info exists date_now] { set date_now "" }
-    set tmp_date [string range $line1 74 81]
-    if { $cbb(debug) } { puts "$date_now - $tmp_date" }
+    set tmp_date [string range $line1 72 79]
+    if { $cbb(debug) } { puts "$date - $tmp_date" }
 
     if { $negative } {
-	# Future transactions in paler colour
-	if { $tmp_date > $date_now } {
-	    .trans.list insert end "$line1\n" futnegcolor1
-	    .trans.list insert end "$line2\n" futnegcolor2
-	} else {
-	    .trans.list insert end "$line1\n" negcolor1
-	    .trans.list insert end "$line2\n" negcolor2
-	}
+	.trans.list insert end "$line1\n" negcolor1
+	.trans.list insert end "$line2\n" negcolor2
     } else {
-	# Future transactions in paler colour
-	if { $tmp_date > $date_now } {
-	    .trans.list insert end "$line1\n" futcolor1
-	    .trans.list insert end "$line2\n" futcolor2
-	} else {
-	    .trans.list insert end "$line1\n" color1
-	    .trans.list insert end "$line2\n" color2
-	}
+	.trans.list insert end "$line1\n" color1
+	.trans.list insert end "$line2\n" color2
     }
 
     if { $tmp_date <= $date } {
@@ -649,9 +549,7 @@ proc update_globals result {
     set key [lindex $pieces 0]
     set date [lindex $pieces 1]
     if { [string length $date] == 6 } {
-	puts "invalid date in udpate_globals()"
-	exit
-	set year [full_year [string range $date 0 1]]
+	set year "$cbb(century)[string range $date 0 1]"
 	set month [string range $date 2 3]
 	set day [string range $date 4 5]
     } else {
@@ -660,9 +558,9 @@ proc update_globals result {
 	set day [string range $date 6 7]
     }
     if { $cbb(date_fmt) == 1 } {
-        set nicedate "$month/$day/$year"
+        set nicedate "$month/$day/[string range $year 2 3]"
     } else {
-        set nicedate "$day.$month.$year"
+        set nicedate "$day.$month.[string range $year 2 3]"
     }
     set check [lindex $pieces 2]
     set desc [lindex $pieces 3]
@@ -726,7 +624,7 @@ proc find_index_from_key args {
     }
 
     set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ]
-    set key [string range $line 74 end]
+    set key [string range $line 72 end]
 
     if { $cbb(debug) } { puts "target = $newkey  current = $key" }
 
@@ -735,7 +633,7 @@ proc find_index_from_key args {
 	while { [expr [string compare "$newkey" "$key"] == -1 && $cbb(index1) > 0]} {
 	    set cbb(index1) [expr $cbb(index1) - 2]
 	    set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ]
-            set key [string range $line 74 end]
+            set key [string range $line 72 end]
 	    if { $cbb(debug) } { puts "target = $newkey  current = $key" }
 	}
 	return [expr $cbb(index1)]
@@ -756,14 +654,14 @@ proc find_index_from_date date {
     set index [listGetSize]
 
     set line [.trans.list get ${index}.0 ${index}.0lineend ]
-    set linedate [string range $line 74 81]
+    set linedate [string range $line 72 79]
 
     if { $cbb(debug) } { puts "target = $date  current = $linedate" }
 
     while { [expr [string compare "$date" "$linedate"] == -1 && $index > 0]} {
 	set index [expr $index - 2]
 	set line [.trans.list get ${index}.0 ${index}.0lineend ]
-	set linedate [string range $line 74 81]
+	set linedate [string range $line 72 79]
 	if { $cbb(debug) } { puts "target = $date  current = $linedate" }
     }
 
@@ -800,12 +698,12 @@ proc update_rest args {
     if { $cbb(debug) } { puts "deleting from:  $cbb(index1).0 to end" }
 
     set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ]
-    set key [string range $line 74 end]
+    set key [string range $line 72 end]
     .trans.list configure -state normal
     .trans.list delete $cbb(index1).0 end
     .trans.list configure -state disabled
  
-    if { $cbb(debug) } { puts [string range $line 74 end] }
+    if { $cbb(debug) } { puts [string range $line 70 end] }
     if { $cbb(debug) } { puts "adding entries from $key to end" }
 
     if { $cbb(index1) == 1 } {
@@ -831,10 +729,10 @@ proc update_rest args {
         set cutcom [string range $com 0 14]
 
 	listAddTrans \
-		[format "%5s  %-10s  %-15s  %9.2f  %9.2f  %-1s  %9.2f %14s" \
+		[format "%5s  %-8s  %-15s  %9.2f  %9.2f  %-1s  %9.2f %14s" \
 		$cutcheck $nicedate $cutdesc $debit $credit $cleared $total \
 		$key] \
-		[format "%5s  %-10s  %-15s  %-9s %39s" "" "" $cutcom $nicecat \
+		[format "%5s  %-8s  %-15s  %-9s %39s" "" "" $cutcom $nicecat \
 		$key] 
 
         # try keep the selection with the original transaction
@@ -888,7 +786,7 @@ proc update_line args {
     if { $cbb(debug) } { puts "deleting from:  $cbb(index1) to $cbb(index2)" }
 
     set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ]
-    set key [string range $line 74 end]
+    set key [string range $line 72 end]
     .trans.list configure -state normal
     .trans.list delete $cbb(index1).0 [expr $cbb(index2) + 1].0
     .trans.list configure -state disabled
@@ -911,11 +809,11 @@ proc update_line args {
 
     .trans.list configure -state normal
     .trans.list insert $cbb(index1).0 \
-           [format "%5s  %-10s  %-15s  %9.2f  %9.2f  %-1s  %9.2f %14s\n" \
+           [format "%5s  %-8s  %-15s  %9.2f  %9.2f  %-1s  %9.2f %14s\n" \
            $cutcheck $nicedate $cutdesc $debit $credit $cleared $total \
 	   $key] color1
     .trans.list insert $cbb(index2).0 \
-           [format "%5s  %-10s  %-15s  %-9s %39s\n" "" "" $cutcom $nicecat \
+           [format "%5s  %-8s  %-15s  %-9s %39s\n" "" "" $cutcom $nicecat \
 	   $key] color2
     .trans.list configure -state disabled
 
@@ -977,8 +875,7 @@ proc update_entry_area lineindex {
     }
 
     set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ] 
-    set key [string range $line 74 end]
-    if { $cbb(debug) } { puts "looking for $key" }
+    set key [string range $line 72 end]
 
     puts $eng "find_trans $key"; flush $eng
     gets $eng result
@@ -989,7 +886,7 @@ proc update_entry_area lineindex {
     }
 
     # warn if about to edit a closed transaction
-    if { "$cleared" == "x" || "$cleared" == "X" } {
+    if { "$cleared" == "x" } {
 	cbbWindow.ok "You are about to edit a ``Closed'' transaction.  \
 		Hopefully you know what you are doing."
 	tkwait window .ok
@@ -1014,8 +911,6 @@ proc done_entering {} {
 
     if { $cbb(debug) } { puts "Done entering ..." }
 
-    set savedate $date
-
     # check for a valid file
     if { "$cbb(cur_file)" == "noname.cbb" } {
 	cbbWindow.ok "You must Make or Load an Account First."
@@ -1033,7 +928,7 @@ proc done_entering {} {
     # do some consistency checking here
     if { "$desc" == "" } {
 	cbbWindow.yesno "You have not entered anything in the description \
-		field.  Would you like to continue?" yes
+		field.  Would you like to continue?"
 	tkwait window .yesno
 	if { "$yesno(result)" != "yes" } {
 	    return
@@ -1061,7 +956,9 @@ proc done_entering {} {
     set month [pad $month]
     set day [pad $day]
     set year [pad $year]
-
+    if { [string length $year] == 2 } {
+	set year $cbb(century)$year
+    }
     if { $cbb(date_fmt) == 1 } {
         if { $cbb(debug) } { puts "$month/$day/$year" }
         set nicedate "$month/$day/$year"
@@ -1078,7 +975,7 @@ proc done_entering {} {
             set cat $result
         } elseif { "$cat" == "" } {
 	    cbbWindow.yesno "You have not entered anything in the category \
-		    field.  Would you like to continue?" yes
+		    field.  Would you like to continue?"
 	    tkwait window .yesno
 	    if { "$yesno(result)" != "yes" } {
 	        return
@@ -1097,7 +994,7 @@ proc done_entering {} {
 
     # verify cleared field
     set cleared [string range $cleared 0 0]
-    if { "$cleared" == "x" || "$cleared" == "X" } {
+    if { "$cleared" == "x" } {
         # ok
     } elseif { "$cleared" == "*" } {
         # ok
@@ -1182,8 +1079,6 @@ proc done_entering {} {
     goto $cbb(selected)
 
     clear_entry_area
-
-    set date $savedate
 }
 
 
@@ -1204,7 +1099,7 @@ proc delete_trans lineindex {
     }
 
     set line [.trans.list get $cbb(index1).0 $cbb(index1).0lineend ]
-    set key [string range $line 74 end]
+    set key [string range $line 72 end]
 
     # first record the official version of this transaction so we can be
     # able to undelete it later
@@ -1220,9 +1115,9 @@ proc delete_trans lineindex {
 	tkwait window .ok
     }
 
-    if { "$cleared" == "x" || "$cleared" == "X" } {
+    if { "$cleared" == "x" } {
 	cbbWindow.yesno "You are deleting a ``Closed'' transaction.  Continue \
-		with delete?" no
+		with delete?"
 	tkwait window .yesno
 	
 	if { "$yesno(result)" == "yes" } {
@@ -1276,28 +1171,29 @@ proc goto line {
 
 
 proc acctSetClean { } {
-    global cbb words
+    global cbb
 
     set cbb(clean) 1
     if { [winfo exists .bar.save] } {
-	.bar.save configure -text $words(button_save)
-	cbb_set_balloon .bar.save $words(button_save_balloon_clean)
+	.bar.save configure -text "Save"
+	cbb_set_balloon .bar.save "Save the current file (file is clean)"
     }
 
-    # update account listbox (if it exists)
-    if { [winfo exists .acct.list] } {
+    # update account listbox
+    if { [info exists cbb(cur_file)] } {
         load_acct_listbox
     }
 }
 
 
 proc acctSetDirty { } {
-    global cbb words
+    global cbb
     
     set cbb(clean) 0
     if { [winfo exists .bar.save] } {
-	.bar.save configure -text $words(button_save_excl)
-	cbb_set_balloon .bar.save $words(button_save_balloon_dirty)
+	.bar.save configure -text "Save!"
+	cbb_set_balloon .bar.save \
+		"Save the current file (file has been changed)"
     }
 }
 
@@ -1307,3 +1203,169 @@ proc acctIsDirty { } {
 
     return [expr 1 - $cbb(clean)]
 }
+
+
+# ----------------------------------------------------------------------------
+# $Log: main.tcl,v $
+# Revision 2.27  1997/06/12 21:53:14  curt
+# Applied more patches from Martin Schenk <schenkm@ping.at>.  His changes
+# greatly improved and developed the preferences menu so it is now actually
+# usable to set preferences.
+# Current data file is now saved in ~/.cbbcur.tcl
+#
+# Revision 2.26  1997/05/06 01:00:25  curt
+# Added patches contributed by Martin Schenk <schenkm@ping.at>
+# - Default to umask of 066 so .CBB files get created rw by owner only
+# - Added support for pgp encrypting data files
+# - Added support for displaying only recent parts of files (avoids
+#   waiting to load in lots of old txns you don't currently need.)
+# - Added a feature to "cache" whole accounts in the perl engine so
+#   that switching between accounts can be faster.
+# - The above options can be turned on/off via the preferrences menu.
+#
+# Revision 2.25  1997/04/12 01:15:26  curt
+# Display current balance rather than ending balance in the account list
+# box.  This makes a difference if you like to insert future transactions.
+#
+# Revision 2.24  1997/04/11 20:26:53  curt
+# $index1, $index2 wrapped up so they are now $cbb(index1), and $cbb(index2)
+#
+# Revision 2.23  1997/04/04 22:50:20  curt
+# Tweaked the previous fix.
+#
+# Revision 2.22  1997/04/04 18:44:48  curt
+# Commented out some old menubar baggage.
+# Fixed a harmless, but annoying bug that caused a pop up tk error message
+# on occasion when manipulating the account list box.
+#
+# Revision 2.21  1997/04/03 03:54:49  curt
+# Enable auto save without prompting when switching to a new account.
+# Contributed by Jonathan I. Kamens <jik@kamens.brookline.ma.us>
+#
+# Revision 2.20  1997/04/03 03:42:20  curt
+# Heading, line 2 color was hardcoded rather than honoring the header color
+# variable.
+#
+# Revision 2.19  1997/03/04 03:22:39  curt
+# Fixed bug which showed up when hitting '+' in a blank check # field after
+# an account had been loaded, but before any transactions with a check number
+# had been added.
+#
+# Revision 2.18  1997/02/19 18:08:06  curt
+# Fixed a bug with long check numbers (> 5 char) in the balance window.
+# Nailed a bug which caused cbb to forget the last check # entered when
+# using +/- in the check number field.
+#
+# Revision 2.17  1997/01/28 03:25:24  curt
+# Force strict scoping in all perl scripts.
+#
+# Revision 2.16  1997/01/16 19:15:42  curt
+# Miscellaneous interface tweaks.
+#
+# Revision 2.15  1997/01/10 22:03:32  curt
+# Transfer fixups and a few other misc. fixes contributed by
+#   Lionel Mallet <Lionel.Mallet@sophia.inria.fr>
+#
+# Revision 2.14  1997/01/09 04:03:06  curt
+# Allow user to specify colors of alternating transaction lines.
+#
+# Revision 2.13  1997/01/09 03:56:59  curt
+# Added contrib script loan.pl.
+# User sizable account list.
+# Removed some old gnuplot baggage from install.pl.
+#
+# Revision 2.12  1997/01/02 04:38:36  curt
+# Changes over the 1996 holidays:
+#   - Converted listbox to text widget.  This allows us to do nice
+#     things with alternating background colors, highliting, red
+#     negative numbers, etc.
+#   - Negative transactions are now drawn in red.
+#   - Added a Goto <Today> option.
+#   - <Home> & <End> were double bound.  Now, listbox can be traversed with
+#     <Meta-Home> and <Meta-End>
+#
+# Revision 2.11  1996/12/17 20:15:44  curt
+# Version incremented to 0.70.
+# No longer save running total in .cbb files.
+# Miscellaneous tweaks.
+#
+# Revision 2.10  1996/12/17 14:54:00  curt
+# Updated copyright date.
+#
+# Revision 2.9  1996/12/16 04:18:21  curt
+# Continuing the great overhaul of December 1996.
+#
+# Revision 2.8  1996/12/14 17:15:23  curt
+# The great overhaul of December '96.
+#
+# Revision 2.7  1996/12/13 01:26:59  curt
+# Worked on getting reports.tcl to work smoothly.
+#
+# Revision 2.6  1996/12/11 18:33:38  curt
+# Ran a spell checker.
+#
+# Revision 2.5  1996/12/11 04:32:31  curt
+# Several minor tweaks.
+#
+# Revision 2.4  1996/12/11 01:03:44  curt
+# Added balloon help support.
+#
+# Revision 2.3  1996/12/09 14:38:23  curt
+# Added "ok" and "cancel" buttons to entry area.  Tweaked check# and data +/-
+# bindings.
+#
+# Revision 2.2  1996/12/08 07:40:01  curt
+# Rearranged quite a bit of code.
+# Put most global variables in cbb() structure.
+#
+# Revision 2.1  1996/12/07 20:38:16  curt
+# Renamed *.tk -> *.tcl
+#
+# Revision 2.10  1996/10/03 04:49:00  curt
+# Fixed an inconsistency in &raw_date() in common.pl (with how it was
+# called.)
+#
+# Version now is 0.67-beta-x
+#
+# Revision 2.9  1996/10/03 03:57:37  curt
+# Adjusted spacing of 2nd entry line so fields better align with the first.
+#
+# Revision 2.8  1996/10/02 19:37:20  curt
+# Replaced instances of hardcoded century (19) with a variable.  We need to
+# know the current century in cases where it is not provided and it is
+# assumed to be the current century.  Someday I need to figure out how
+# to determine the current century, but I have a couple of years to do it. :-)
+#
+# I still need to fix conf-reports and reports.pl
+#
+# Revision 2.7  1996/10/01 20:25:38  curt
+# Added better handling of unknown category when trying to "commit" a
+# transaction.
+#
+# Revision 2.6  1996/09/30 15:14:38  curt
+# Updated CBB URL, and hardwired wish path.
+#
+# Revision 2.5  1996/09/25 17:45:42  curt
+# Revamped tab completions in description and category fields.
+# Fixed a problem with autohiliting.  When tabbing to a blank field, we used
+# to leave the previous hilited field hilited.
+#
+# Revision 2.4  1996/08/29 14:22:33  curt
+# <Meta-Tab> changed to <Control-Tab> in desc field.
+#
+# Revision 2.3  1996/07/13 02:57:49  curt
+# Version 0.65
+# Packing Changes
+# Documenation changes
+# Changes to handle a value in both debit and credit fields.
+#
+# Revision 2.2  1996/03/03  00:16:13  curt
+# Modified Files:  cbb categories.pl wrapper.pl file.tk main.tk menu.tk
+#   Added an account list at the bottom of the screen.  Thanks to:
+#   Cengiz Alaettinoglu <cengiz@ISI.EDU> for this great addition.
+#
+# Revision 2.1  1996/02/27  05:35:48  curt
+# Just stumbling around a bit with cvs ... :-(
+#
+# Revision 2.0  1996/02/27  04:43:01  curt
+# Initial 2.0 revision.  (See "Log" files for old history.)
